==> jscatter-1.5.1.2.dev20230119.tar.gz: jscatter-1.5.1.2.dev20230119/src/jscatter/doc/source/sphinxext/fulltoc.py <==
# -*- encoding: utf-8 -*-
#
# Copyright © 2012 New Dream Network, LLC (DreamHost)
#
# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

# RB 2022: included explicit in jscatter from original source
# changes to get again toctree with maxdeepth

from sphinx import addnodes


def html_page_context(app, pagename, templatename, context, doctree):
    """Event handler for the html-page-context signal.

    Modifies the context directly.

     - Replaces the 'toc' value created by the HTML builder with one
       that shows all document titles and the local table of contents.
     - Sets display_toc to True so the table of contents is always
       displayed, even on empty pages.
     - Replaces the 'toctree' function with one that uses the entire
       document structure, and uses only prune and collapse.

    """
    rendered_toc = get_rendered_toctree(app.builder, pagename)
    context['toc'] = rendered_toc
    context['display_toc'] = True  # force toctree to display

    def make_toctree(collapse=True):
        return get_rendered_toctree(app.builder,
                                    docname=pagename,
                                    prune=True,
                                    collapse=collapse,
                                    maxdeepth=2
                                    )
    context['toctree'] = make_toctree


def get_rendered_toctree(builder, docname, prune=True, collapse=True, maxdeepth=2):
    """Build the toctree relative to the named document,
    with the given parameters, and then return the rendered
    HTML fragment.
    """
    fulltoc = build_full_toctree(builder,
                                 docname,
                                 prune=prune,
                                 collapse=collapse,
                                 maxdeepth=maxdeepth
                                 )
    rendered_toc = builder.render_partial(fulltoc)['fragment']
    return rendered_toc


def build_full_toctree(builder, docname, prune, collapse, maxdeepth):
    """Return a single toctree starting from docname containing all
    sub-document doctrees.
    """
    env = builder.env
    doctree = env.get_doctree(env.config.master_doc)
    toctrees = []
    for toctreenode in doctree.traverse(addnodes.toctree):
        # RB: To limit the deepth of the toctree we need prune=True and maxdepth
        toctree = env.resolve_toctree(docname, builder, toctreenode, collapse=collapse,
                                      prune=prune, maxdepth=maxdeepth)
        toctrees.append(toctree)
    if not toctrees:
        return None

    result = toctrees[0]
    for toctree in toctrees[1:]:
        if toctree:
            result.extend(toctree.children)

    env.resolve_references(result, docname, builder)
    return result


def setup(app):
    app.connect('html-page-context', html_page_context)

==> jscatter-1.7.5.tar.gz: jscatter-1.7.5/src/jscatter/doc/source/sphinxext/fulltoc.py <==
# -*- encoding: utf-8 -*-
#
# Copyright © 2012 New Dream Network, LLC (DreamHost)
#
# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

# RB 2022: included explicit in jscatter from original source
# changes to get again toctree with maxdepth

from sphinx import addnodes


def html_page_context(app, pagename, templatename, context, doctree):
    """Event handler for the html-page-context signal.

    Modifies the context directly.

     - Replaces the 'toc' value created by the HTML builder with one
       that shows all document titles and the local table of contents.
     - Sets display_toc to True so the table of contents is always
       displayed, even on empty pages.
     - Replaces the 'toctree' function with one that uses the entire
       document structure, and uses only prune and collapse.

    """
    rendered_toc = get_rendered_toctree(app.builder, pagename)
    context['toc'] = rendered_toc
    context['display_toc'] = True  # force toctree to display

    def make_toctree(collapse=True):
        return get_rendered_toctree(app.builder,
                                    docname=pagename,
                                    prune=True,
                                    collapse=collapse,
                                    maxdeepth=2
                                    )
    context['toctree'] = make_toctree


def get_rendered_toctree(builder, docname, prune=True, collapse=True, maxdeepth=2):
    """Build the toctree relative to the named document,
    with the given parameters, and then return the rendered
    HTML fragment.
    """
    fulltoc = build_full_toctree(builder,
                                 docname,
                                 prune=prune,
                                 collapse=collapse,
                                 maxdeepth=maxdeepth
                                 )
    rendered_toc = builder.render_partial(fulltoc)['fragment']
    return rendered_toc


def build_full_toctree(builder, docname, prune, collapse, maxdeepth):
    """Return a single toctree starting from docname containing all
    sub-document doctrees.
    """
    env = builder.env
    doctree = env.get_doctree(env.config.master_doc)
    toctrees = []
    for toctreenode in doctree.traverse(addnodes.toctree):
        # RB: To limit the depth of the toctree we need prune=True and maxdepth
        toctree = env.resolve_toctree(docname, builder, toctreenode, collapse=collapse,
                                      prune=prune, maxdepth=maxdeepth)
        toctrees.append(toctree)
    if not toctrees:
        return None

    result = toctrees[0]
    for toctree in toctrees[1:]:
        if toctree:
            result.extend(toctree.children)

    env.resolve_references(result, docname, builder)
    return result


def setup(app):
    app.connect('html-page-context', html_page_context)
